@@ -1,4 +1,4 @@
-# @(#)$Ident: CPANTesting.pm 2013-04-29 19:24 pjf ;
+# @(#)$Ident: CPANTesting.pm 2013-05-10 21:16 pjf ;
 # Bob-Version: 1.7
 
 package CPANTesting;
@@ -15,7 +15,6 @@ sub is_testing { !! ($ENV{AUTOMATED_TESTING} || $ENV{PERL_CR_SMOKER_CURRENT}
 sub should_abort {
    is_testing() or return 0;
 
-   $ENV{PERL5LIB} =~ m{ Archibald }msx and warn "Host: ${host}\n";
    $host eq q(xphvmfred) and return
       "Terminated Stauner ${host} - cc06993e-a5e9-11e2-83b7-87183f85d660";
 
@@ -28,16 +27,12 @@ sub test_exceptions {
    $p->{stop_tests} and return 'CPAN Testing stopped in Build.PL';
 
    $osname eq q(mirbsd)          and return 'Mirbsd OS unsupported';
-   $host   eq q(slack64)         and return
-      "Stopped Bingos  ${host} - IPC::ShareLite - no space left on device";
-   $host   eq q(falco)           and return
-      "Stopped Bingos  ${host} - IPC::ShareLite - no space left on device";
    $host   =~ m{ nigelhorne }msx and return
       "Stopped Horne   ${host} - irrelevant Perl versions";
-   $host   eq q(c-9d2392d06fcb4) and return
-      "Stopped Ciornii ${host} - aa18dea5-6bfb-1014-97a2-fbb5402793bb";
-   $host   eq q(k83)             and return
-      "Stopped Konig   ${host} - cfd60888-aea9-11e2-882d-0004c1508286";
+#   $host   eq q(c-9d2392d06fcb4) and return
+#      "Stopped Ciornii ${host} - aa18dea5-6bfb-1014-97a2-fbb5402793bb";
+#   $host   eq q(k83)             and return
+#      "Stopped Konig   ${host} - cfd60888-aea9-11e2-882d-0004c1508286";
    return 0;
 }
 
